import Api from '../../model/api'
import User from '../../model/user'
import {
    getDataSet,
    getEventParam,
    toast
} from "../../utils/utils";
import {
    htmlTypes,
    liveSources,
    videoTypes
} from "../../model/enum";
import Route from "../../model/route";

const app = getApp();
app.Base({
    data: {
        id: "", //用来区分是否是通过卡片分享进行来的用户,当id存在值的时候是guest
        homeData: {
            notice: {
                noticeContent: ''
            },
            carouselList: [],
            classInfo: {
                opened: 0,
                notYetOpened: 0,
                history: 0,
            },
            dictList: [],
        },
        tabs: [{
                title: "直播课程",
                icon: '/images/tab_live.png'
            },
            {
                title: "教材阅读",
                icon: '/images/tab_book.png',
                url: "/pages/book/book"
            },
            {
                title: "精品课程",
                icon: '/images/tab_course.png',
                url: "/pages/course/course"
            },
            {
                title: "社区交流",
                icon: '/images/tab_exchange.png'
            }
        ],
        active: 0,
        dictType: '',
        dictValue: '',
        showLiveList: false,
        actions: [],
        //等待跳转直播页面的结果，加入该变量解决在本页面登录成功后跳转直播页面多(两)次问题
        waitToLive: false,
        // showLiveDot: false,
        liveCourseCount: 0
    },

    async onLoad(options) {
        const {
            id,
            guest
        } = options;
        if (guest == 'true') {
            this.id = id;
        }
        const res = await Api.getIndex();
        const dictType = res.data.dictList[0].dictType;
        const dictValue = res.data.dictList[0].dictValue;
        this.setData({
            homeData: res.data,
            dictType,
            dictValue
        })
        this.selectComponent('#tabs').resize();
    },
    async setUserLiveCourseCount(){
        let isLogin = User.isLogin();
        let liveCourseCount = 0;
        if(isLogin) {
            const res = await Api.getUserLiveId(true);
            // let showLiveDot = true;
            if (res.data && res.data.length > 0) {
                // showLiveDot = true;
                liveCourseCount = res.data.length;
            }
        }   
        console.log(liveCourseCount);
        this.setData({
            // showLiveDot
            liveCourseCount
        });
    },
    async onShow() {
        // console.log(' trigger index page onShow ');
        // console.log('onShow -> before ==> this.id = ', this.id);
        this.setUserLiveCourseCount();
        if (!this.id) {
            return;
        }
        await User.checkLogin(); //游客如果在登录页点了返回，会一直触发该函数（返回就重新跳转到登录页） 这里需要注意，如果以后需要修改为只触发一次，把它移动到下面的if语句中
        if (!this.waitToLive) {
            this.waitToLive = true;
            // console.log('executed checkLogin!!');
            // await User.checkLogin(); //游客如果一直不登录，会一直触发该函数 这里需要注意，如果以后需要修改为只触发一次，去掉注释
            let flag = await User.gotoLive(this.id).finally(() => {
                this.waitToLive = false;
            });
            if (flag) {
                this.id = "";
                // console.log('onShow -> after ==> this.id = ', this.id);
            }
        }
    },
    async toNotice(e) {
        await User.checkLogin();
        Route.toNotice()
    },
    toBannerDetail(e) {
        const item = getEventParam(e, "item");
        Route.toNews(htmlTypes.BANNER, item.id, item.articleTitle, "")
    },
    async toClickGrid(e) {
        const title = getDataSet(e, "title");
        if ('直播课程' == title) {
            await this.findLive();
            // Route.toLive(liveSources.GUEST,
            //   "分享直播",
            //   "3", "333", "user.name","")
        } else if ('社区交流' == title) {
            await User.checkLogin();
            Route.tocCommunity()
        }
    },
    toNewsDetail(e) {
        const item = getDataSet(e, "item");
        const title = getDataSet(e, "title");
        if (item.isNews) {
            Route.toNews(htmlTypes.NEWS, item.id, item.title, "")
        } else {
            Route.toVideo(item.id, videoTypes.COMMON, title)
        }
    },
    toSchoolIntrouce() {
        Route.toSchoolIntrouce();
    },
    async onChange(e) {
        const index = getEventParam(e, "index");
        const dictType = this.data.homeData.dictList[index].dictType;
        const dictValue = this.data.homeData.dictList[index].dictValue;
        this.setData({
            active: index,
            dictType,
            dictValue
        }, async () => {
            this.changeResetData(this);
        })
    },
    async requestData() {
        const res = await Api.getNewsList({
            dictType: this.data.dictType,
            dictValue: this.data.dictValue,
            pageNum: this.pageNum,
            pageSize: this.pageSize
        });
        res.data.rows = res.data.rows.map(item => {
            return {
                title: item.articleTitle || item.videoName,
                visitedCount: item.visitedCount,
                cover: item.articleImg || item.videoImg,
                id: item.id,
                isNews: !!item.articleTitle
            }
        });
        return res;
    },
    async onPullDownRefresh() {
        const res = await Api.getIndex(true);
        const dictType = res.data.dictList[0].dictType;
        const dictValue = res.data.dictList[0].dictValue;
        this.setData({
            homeData: res.data,
            dictType,
            dictValue,
            active: 0
        })
        this.selectComponent('#tabs').resize();
        this.setUserLiveCourseCount();
    },
    async findLive() {
        await User.checkLogin();
        const res = await Api.getUserLiveId(true);
        if (res.data && res.data.length > 0) {
            if (res.data.length == 1) {
                let item = res.data[0];
                let id = item.scheduleId;
                let eId = item.eStudentId;
                let eName = item.eduStuName;
                Route.toLive(liveSources.DEFAULT,
                    item.courseCeremoneyName,
                    id, eId, eName, item.courseThumbnailUrl)
            } else {
                this.setData({
                    actions: res.data.map(item => {
                        item.name = `${item.teamName}-${item.courseCeremoneyName}`;
                        return item;
                    }),
                    showLiveList: true
                })
            }
        } else {
            toast("没有进行的直播")
        }
    },
    onClose() {
        this.setData({
            showLiveList: false
        });
    },
    async onSelect(e) {
        const scheduleId = getEventParam(e, "scheduleId");
        const eStudentId = getEventParam(e, "eStudentId");
        const eduStuName = getEventParam(e, "eduStuName");
        const courseCeremoneyName = getEventParam(e, "courseCeremoneyName");
        const courseThumbnailUrl = getEventParam(e, "courseThumbnailUrl");
        Route.toLive(liveSources.DEFAULT, courseCeremoneyName,
            scheduleId, eStudentId, eduStuName, courseThumbnailUrl);
    },
    // 页面被用户分享时执行
    onShareAppMessage() {}
})